\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{letterhead}
              [1997/08/28 v1.1c
               LaTeX letterhead class]
%
%  LaTeX2e letterhead class [1997/08/28 v1.1c -- generic COSC defaults]
%
%  Provides:	\name  \degree  \position  \phone  \email  \url  \signature
%		\dateit  \whoto  \opening  \closing
%
%  Option:  noheader		- suppress letterhead at top of page, 
%				  which contains the following:
%  \name{<my_name>}		- default {Postmaster} 
%  \degree{<my_degrees>}	- default {}
%  \position{<my_position>}	- default {Staff}
%  \phone{<my_phone>}		- default {364 2362}
%  \email{<my_email>}		- default {postmaster@cosc.canterbury.ac.nz}
%  \url{<my_url>}		- default {http://www.cosc.canterbury.ac.nz/}
%  \signature{<my_signature>}	- default {<my_name>} (used in \closing)
%
%  \dateit{<date>}		- add the date ({\today} for today's <date>)
%  \whoto{<address>}		- address of the recipient
%  \opening{<greeting>}		- opening greeting (appends a comma)
%  \closing{<signoff>}		- closing signoff (appends a comma)
%   
%  More than one letter per file is o.k. 
%  Do a \clearpage or equivalent in between;
%  the first page will not be numbered, but subsequent ones will.
%
% Example usage of `letterhead' class (see also `myletter' class):
%
% \documentclass[times]{letterhead}
%
% \name{Dr. Bruce J. McKenzie}
% \degree{B.Sc.(Hons), Ph.D.}
% \position{Head of Department}
% \phone{364 2349}
% \email{B.McKenzie@cosc.canterbury.ac.nz}
% \url{http://www.cosc.canterbury.ac.nz/\~{}bruce}
% \signature{Dr. B. J. McKenzie\\Head of Department}
%
% \begin{document}
% \dateit{\today}
% \whoto{Santa Claus,\\Head of Elves,\\North Pole.}
% 
% \opening{Dear Santa}
% 
% Enclosed is my wish list.
% 
% \closing{Yours sincerely}
% \end{document}
% 

\newcommand{\headercmd}{\headit}
\DeclareOption{noheader}{\renewcommand{\headercmd}{}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

\LoadClass[a4paper]{article}
%not based on letter as don't want to start half way down the page...
\RequirePackage[dvips]{epsfig}
%at comes _after_ article (or other base style) because it redefines \output
%failure to do this leads to overfull vboxes and general p.i.t.a.
\RequirePackage{oldat}

\AtBeginDocument{\headercmd}

\newfont{\namefont}{phvro at 10pt}
\newfont{\degreefont}{phvro at 6pt}
\newfont{\headfont}{phvb at 10pt}
\newfont{\addrfont}{phvr at 10pt}
\newfont{\emailfont}{cmtt10}
\newfont{\urlfont}{cmtt10}

\newcommand{\@name}{Postmaster}
\newcommand{\name}[1]{\renewcommand{\@name}{#1}}
\newcommand{\@degree}{}
\newcommand{\degree}[1]{\renewcommand{\@degree}{#1}}
\newcommand{\@position}{Staff}
\newcommand{\position}[1]{\renewcommand{\@position}{#1}}
\newcommand{\@phone}{364 2362}
\newcommand{\phone}[1]{\renewcommand{\@phone}{#1}}
\newcommand{\@email}{postmaster@cosc.canterbury.ac.nz}
\newcommand{\email}[1]{\renewcommand{\@email}{#1}}
\newcommand{\@url}{http://www.cosc.canterbury.ac.nz/}
\newcommand{\url}[1]{\renewcommand{\@url}{#1}}
\newcommand{\www}[1]{\renewcommand{\@url}{#1}}
\newcommand{\@signature}{\@name}
\newcommand{\signature}[1]{\renewcommand{\@signature}{#1}}

\newcommand{\headit}{%
%\clearpage
\setcounter{page}{1}
\thispagestyle{empty}
\at(30mm,4mm){\epsfbox{cushield.ps}}
\at(60mm,10mm){
\parbox[t]{11.5cm}{
	{\namefont \@name} %
	{\degreefont \@degree}
	\\
	{\headfont \@position, Department of Computer Science}\\
	\rule[8pt]{11.3cm}{0.6pt}\\
	}
}
\at(60mm,21mm){
\parbox[t]{11.5cm}{
	{\headfont University of Canterbury} %
	{\addrfont Private Bag 4800, Christchurch, New Zealand}
	}
}
\at(102mm,25mm){
\parbox[t]{8.8cm}{
	{\addrfont Voice/mail: +64 (03) \@phone\\}
	{\addrfont Fax: + 64 (03) 364 2569\\}
	{\addrfont Email: {\emailfont \@email}\\}
	{\addrfont URL: {\urlfont \@url}\\}
	}
}
\mbox{}\par\mbox{}
}

\def\today
{{\number\day
  \space
  \ifcase\month\or
    January\or February\or March\or April\or May\or June\or July\or
    August\or September\or October\or November\or December%
    \fi
  \space\number\year}}

\newcommand{\dateit}[1]{%
\vspace{\baselineskip}
{\hfill {\addrfont #1}}\par
}

\newcommand{\whoto}[1]{%
\vspace*{\baselineskip}
\noindent #1 \par}

\newcommand{\opening}[1]{%
\vspace*{\baselineskip}
\mbox{}\\#1,
\par
\vspace*{\baselineskip}
}

\newcommand{\closing}[1]{%
\vspace*{2\baselineskip}
\noindent #1,\\[1.5cm]\@signature \par
}

\newcommand{\signedclosing}[2]{%
\vspace*{2\baselineskip}
\noindent #1,\\\epsfbox{#2}\\\@signature \par
}
\parindent=0pt
\parskip .7em
%
